#!/usr/bin/env python3
# author: @netmanchris



# This section imports required libraries
import json
import requests



HEADERS = {'Accept': 'application/json', 'Content-Type':
    'application/json', 'Accept-encoding': 'application/json'}

def get_ap_info_all(auth, url):
    """
    function takes no input to RESTFUL call to HP IMC
    :param auth: requests auth object #usually auth.creds from auth pyhpeimc.auth.class

    :param url: base url of IMC RS interface #usually auth.url from pyhpeimc.auth.authclass

    :return: list of dictionaries where each element of the list represents a single wireless access point which has been
    discovered in the HPE IMC WSM module

    :rtype: list

    >>> from pyhpeimc.auth import *

    >>> from pyhpeimc.wsm.apinfo import *

    >>> auth = IMCAuth("http://", "10.101.0.203", "8080", "admin", "admin")

    >>> get_ap_info_all(auth.creds, auth.url)
    [{'acDevId': '31',
  'acIpAddress': '10.10.10.5',
  'acLabel': 'HP830_WSC',
  'apAlias': 'Campus A Floor 1 Conference Room',
  'connectType': '3',
  'hardwareVersion': '',
  'ipAddress': '',
  'isFit': '1',
  'label': 'Campus A Floor 1 Conference Room',
  'location': '',
  'macAddress': '',
  'onlineClientCount': '0',
  'onlineStatus': '0',
  'serialId': 'CN1BD3209B',
  'softwareVersion': '',
  'ssids': ['fammai', 'famyoung', 'HP_BYOD_830', 'HPLAB'],
  'status': '1',
  'sysName': 'ap1_0006',
  'type': 'MSM460-AM'},
 {'acDevId': '31',
  'acIpAddress': '10.10.10.5',
  'acLabel': 'HP830_WSC',
  'apAlias': '',
  'connectType': '3',
  'hardwareVersion': '',
  'ipAddress': '',
  'isFit': '1',
  'label': '26020e_1_0002',
  'location': '',
  'macAddress': '',
  'onlineClientCount': '0',
  'onlineStatus': '0',
  'serialId': '210235A42MB095000401',
  'softwareVersion': '',
  'ssids': ['fammai', 'famyoung', 'HP_BYOD_830', 'HPLAB'],
  'status': '1',
  'sysName': '26020e_1_0002',
  'type': 'WA2620E-AGN'},
 {'acDevId': '31',
  'acIpAddress': '10.10.10.5',
  'acLabel': 'HP830_WSC',
  'apAlias': '',
  'connectType': '3',
  'hardwareVersion': '',
  'ipAddress': '',
  'isFit': '1',
  'label': '26020e_1',
  'location': '',
  'macAddress': '',
  'onlineClientCount': '0',
  'onlineStatus': '0',
  'serialId': '(26020E_1)',
  'softwareVersion': '',
  'ssids': ['fammai', 'famyoung', 'HP_BYOD_830', 'HPLAB'],
  'status': '1',
  'sysName': '26020e_1',
  'type': 'WA2620E-AGN'},
 {'acDevId': '31',
  'acIpAddress': '10.10.10.5',
  'acLabel': 'HP830_WSC',
  'apAlias': '',
  'connectType': '1',
  'hardwareVersion': '',
  'ipAddress': '10.101.0.105',
  'isFit': '1',
  'label': 'msm525_ap4',
  'location': 'UWW',
  'locationList': 'UWW',
  'macAddress': '78:48:59:49:18:C0',
  'onlineClientCount': '3',
  'onlineStatus': '1',
  'serialId': 'CN48GTH03G',
  'softwareVersion': 'V100R005B09D045',
  'ssids': ['famyoung', 'HP_BYOD_830'],
  'status': '1',
  'sysName': 'msm525_ap4',
  'type': '525-WW'},
 {'acDevId': '238',
  'acIpAddress': '10.101.0.236',
  'acLabel': 'Aruba7010',
  'apAlias': 'ac:a3:1e:cd:cf:04',
  'connectType': '1',
  'hardwareVersion': '',
  'ipAddress': '10.101.0.148',
  'isFit': '1',
  'label': 'ac:a3:1e:cd:cf:04',
  'location': 'Lab',
  'locationList': 'Lab',
  'macAddress': 'AC:A3:1E:CD:CF:04',
  'onlineClientCount': '0',
  'onlineStatus': '1',
  'serialId': 'ac:a3:1e:cd:cf:04',
  'softwareVersion': '',
  'status': '1',
  'sysName': 'ac:a3:1e:cd:cf:04',
  'type': '325'},
 {'acDevId': '31',
  'acIpAddress': '10.10.10.5',
  'acLabel': 'HP830_WSC',
  'apAlias': '',
  'connectType': '3',
  'hardwareVersion': '',
  'ipAddress': '',
  'isFit': '1',
  'label': 'msm525_ap2',
  'location': '',
  'macAddress': '',
  'onlineClientCount': '0',
  'onlineStatus': '0',
  'serialId': 'CN48GTH01Q',
  'softwareVersion': '',
  'ssids': ['famyoung', 'HP_BYOD_830'],
  'status': '1',
  'sysName': 'msm525_ap2',
  'type': '525-WW'},
 {'acDevId': '31',
  'acIpAddress': '10.10.10.5',
  'acLabel': 'HP830_WSC',
  'apAlias': '',
  'connectType': '3',
  'hardwareVersion': '',
  'ipAddress': '',
  'isFit': '1',
  'label': 'ap1',
  'location': '',
  'macAddress': '',
  'onlineClientCount': '0',
  'onlineStatus': '0',
  'serialId': '(AP1)',
  'softwareVersion': '',
  'ssids': ['fammai', 'famyoung', 'HP_BYOD_830', 'HPLAB'],
  'status': '1',
  'sysName': 'ap1',
  'type': 'MSM460-AM'},
 {'acDevId': '31',
  'acIpAddress': '10.10.10.5',
  'acLabel': 'HP830_WSC',
  'apAlias': '',
  'connectType': '3',
  'hardwareVersion': '',
  'ipAddress': '10.101.0.110',
  'isFit': '1',
  'label': 'msm525_ap1',
  'location': '',
  'macAddress': '78:48:59:49:10:C0',
  'onlineClientCount': '0',
  'onlineStatus': '0',
  'serialId': 'CN48GTH016',
  'softwareVersion': '',
  'ssids': ['famyoung', 'HP_BYOD_830'],
  'status': '1',
  'sysName': 'msm525_ap1',
  'type': '525-WW'},
 {'acDevId': '68',
  'acIpAddress': '10.101.0.235',
  'acLabel': 'aruba3600.lab.local',
  'apAlias': 'd8:c7:c8:c2:52:4e',
  'connectType': '1',
  'hardwareVersion': '',
  'ipAddress': '10.101.0.106',
  'isFit': '1',
  'label': 'd8:c7:c8:c2:52:4e',
  'location': 'Lab',
  'locationList': 'Lab',
  'macAddress': 'D8:C7:C8:C2:52:4E',
  'onlineClientCount': '0',
  'onlineStatus': '1',
  'serialId': 'd8:c7:c8:c2:52:4e',
  'softwareVersion': '',
  'status': '1',
  'sysName': 'd8:c7:c8:c2:52:4e',
  'type': '105'},
 {'acDevId': '238',
  'acIpAddress': '10.101.0.236',
  'acLabel': 'Aruba7010',
  'apAlias': 'ac:a3:1e:cd:cc:c4',
  'connectType': '1',
  'hardwareVersion': '',
  'ipAddress': '10.101.0.107',
  'isFit': '1',
  'label': 'ac:a3:1e:cd:cc:c4',
  'location': 'Lab',
  'locationList': 'Lab',
  'macAddress': 'AC:A3:1E:CD:CC:C4',
  'onlineClientCount': '0',
  'onlineStatus': '1',
  'serialId': 'ac:a3:1e:cd:cc:c4',
  'softwareVersion': '',
  'status': '1',
  'sysName': 'ac:a3:1e:cd:cc:c4',
  'type': '325'},
 {'acDevId': '238',
  'acIpAddress': '10.101.0.236',
  'acLabel': 'Aruba7010',
  'apAlias': 'ac:a3:1e:ca:6c:9c',
  'connectType': '1',
  'hardwareVersion': '',
  'ipAddress': '10.101.0.149',
  'isFit': '1',
  'label': 'ac:a3:1e:ca:6c:9c',
  'location': 'Lab',
  'locationList': 'Lab',
  'macAddress': 'AC:A3:1E:CA:6C:9C',
  'onlineClientCount': '0',
  'onlineStatus': '1',
  'serialId': 'ac:a3:1e:ca:6c:9c',
  'softwareVersion': '',
  'status': '1',
  'sysName': 'ac:a3:1e:ca:6c:9c',
  'type': '115'},
 {'acDevId': '31',
  'acIpAddress': '10.10.10.5',
  'acLabel': 'HP830_WSC',
  'apAlias': '',
  'connectType': '1',
  'hardwareVersion': '',
  'ipAddress': '10.101.0.107',
  'isFit': '1',
  'label': 'msm525_ap3',
  'location': 'UWW',
  'locationList': 'UWW',
  'macAddress': '78:48:59:49:16:40',
  'onlineClientCount': '2',
  'onlineStatus': '1',
  'serialId': 'CN48GTH031',
  'softwareVersion': 'V100R005B09D045',
  'ssids': ['famyoung', 'HP_BYOD_830'],
  'status': '1',
  'sysName': 'msm525_ap3',
  'type': '525-WW'},
 {'acDevId': '31',
  'acIpAddress': '10.10.10.5',
  'acLabel': 'HP830_WSC',
  'apAlias': '',
  'connectType': '3',
  'hardwareVersion': '',
  'ipAddress': '',
  'isFit': '1',
  'label': 'ap1_0005',
  'location': '',
  'macAddress': '',
  'onlineClientCount': '0',
  'onlineStatus': '0',
  'serialId': 'CN1BD320BF',
  'softwareVersion': '',
  'ssids': ['fammai', 'famyoung', 'HP_BYOD_830', 'HPLAB', 'SCEP_TEST'],
  'status': '1',
  'sysName': 'ap1_0005',
  'type': 'MSM460-AM'}]
    """
    get_ap_info_all_url = "/imcrs/wlan/apInfo/queryApBasicInfo"
    f_url = url + get_ap_info_all_url
    payload = None
    r = requests.get(f_url, auth=auth,
                     headers=HEADERS)  # creates the URL using the payload variable as the contents
    # print(r.status_code)
    try:
        if r.status_code == 200:
            if len(r.text) > 0:
                return json.loads(r.text)['apBasicInfo']
    except requests.exceptions.RequestException as e:
            return "Error:\n" + str(e) + " get_ap_info_all: An Error has occured"

def get_ap_info(ipaddress, auth, url):
    """
    function takes input of ipaddress to RESTFUL call to HP IMC

    :param ipaddress: The current IP address of the Access Point at time of query.

    :param auth: requests auth object #usually auth.creds from auth pyhpeimc.auth.class

    :param url: base url of IMC RS interface #usually auth.url from pyhpeimc.auth.authclass

    :return: Dictionary object with the details of the target access point

    :rtype: dict

    >>> from pyhpeimc.auth import *

    >>> from pyhpeimc.wsm.apinfo import *

    >>> auth = IMCAuth("http://", "10.101.0.203", "8080", "admin", "admin")

    >>> get_ap_info('10.101.0.105',auth.creds, auth.url)
    {'acDevId': '31',
 'acIpAddress': '10.10.10.5',
 'acLabel': 'HP830_WSC',
 'apAlias': '',
 'connectType': '1',
 'hardwareVersion': '',
 'ipAddress': '10.101.0.105',
 'isFit': '1',
 'label': 'msm525_ap4',
 'location': 'UWW',
 'locationList': 'UWW',
 'macAddress': '78:48:59:49:18:C0',
 'onlineClientCount': '3',
 'onlineStatus': '1',
 'serialId': 'CN48GTH03G',
 'softwareVersion': 'V100R005B09D045',
 'ssids': ['famyoung', 'HP_BYOD_830'],
 'status': '1',
 'sysName': 'msm525_ap4',
 'type': '525-WW'}
    """
    get_ap_info_url = "/imcrs/wlan/apInfo/queryApBasicInfoByCondition?ipAddress=" + str(ipaddress)
    f_url = url + get_ap_info_url
    payload = None
    r = requests.get(f_url, auth=auth,
                     headers=HEADERS)  # creates the URL using the payload variable as the contents
    # print(r.status_code)
    try:
        if r.status_code == 200:
            if len(r.text) > 0:
                return json.loads(r.text)['apBasicInfo']
    except requests.exceptions.RequestException as e:
            return "Error:\n" + str(e) + " get_ap_info_all: An Error has occured"





#!/usr/bin/env python3
# author: @netmanchris



# This section imports required libraries
import json
import requests
from pyhpeimc.plat.device import *


HEADERS = {'Accept': 'application/json', 'Content-Type':
    'application/json', 'Accept-encoding': 'application/json'}




def get_vm_host_info(hostip, auth, url):
    """
    function takes hostId as input to RESTFUL call to HP IMC

    :param hostip: int or string of hostip of Hypervisor host

    :param auth: requests auth object #usually auth.creds from auth pyhpeimc.auth.class

    :param url: base url of IMC RS interface #usually auth.url from pyhpeimc.auth.authclass

    :return: Dictionary contraining the information for the target VM host

    :rtype: dict

    >>> from pyhpeimc.auth import *

    >>> from pyhpeimc.plat.vrm import *

    >>> auth = IMCAuth("http://", "10.101.0.203", "8080", "admin", "admin")

    >>>get_vm_host_info('10.101.0.6', auth.creds, auth.url)
    {'cpuFeg': '2297',
 'cpuNum': '40',
 'devId': '76',
 'devIp': '10.101.0.6',
 'diskSize': '0',
 'memory': '114559',
 'parentDevId': '56',
 'porductFlag': '0',
 'serverName': 'esx1.lab.local',
 'vendor': 'HP'}


    """
    hostId = get_dev_details(hostip, auth, url)['id']
    get_vm_host_info_url = "/imcrs/vrm/host?hostId=" + str(hostId)
    f_url = url + get_vm_host_info_url
    payload = None
    r = requests.get(f_url, auth=auth,
                     headers=HEADERS)  # creates the URL using the payload variable as the contents
    # print(r.status_code)
    try:
        if r.status_code == 200:
            if len(r.text) > 0:
                return json.loads(r.text)
        elif r.status_code == 204:
            print("Device is not a supported Hypervisor")
            return "Device is not a supported Hypervisor"
    except requests.exceptions.RequestException as e:
            return "Error:\n" + str(e) + " get_vm_host_info: An Error has occured"

def get_vm_host_vnic(hostip, auth, url):
    """
    function takes hostId as input to RESTFUL call to HP IMC

    :param hostip: int or string of hostip of Hypervisor host

    :param auth: requests auth object #usually auth.creds from auth pyhpeimc.auth.class

    :param url: base url of IMC RS interface #usually auth.url from pyhpeimc.auth.authclass

    :return: list of dictionaries where each element of the list represents a single NIC on the target host

    :rtype: list

    >>> from pyhpeimc.auth import *

    >>> from pyhpeimc.plat.vrm import *

    >>> auth = IMCAuth("http://", "10.101.0.203", "8080", "admin", "admin")

    >>> get_vm_host_vnic('10.101.0.6', auth.creds, auth.url)
    [{'ip': '10.101.0.6',
  'mask': '255.255.255.0',
  'nicName': 'vmk0',
  'serverDevId': '76',
  'vSwitchName': 'vSwitch0',
  'vSwtichKey': 'key-vim.host.VirtualSwitch-vSwitch0'},
 {'ip': '10.101.0.123',
  'mask': '255.255.255.0',
  'nicName': 'vmk1',
  'serverDevId': '76',
  'vSwitchName': 'vSwitch0',
  'vSwtichKey': 'key-vim.host.VirtualSwitch-vSwitch0'},
 {'ip': '',
  'mask': '',
  'nicName': 'vmnic0',
  'serverDevId': '76',
  'vSwitchName': 'vSwitch0',
  'vSwtichKey': 'key-vim.host.VirtualSwitch-vSwitch0'},
 {'ip': '',
  'mask': '',
  'nicName': 'vmnic1',
  'serverDevId': '76',
  'vSwtichKey': ''},
 {'ip': '',
  'mask': '',
  'nicName': 'vmnic2',
  'serverDevId': '76',
  'vSwtichKey': ''},
 {'ip': '',
  'mask': '',
  'nicName': 'vmnic3',
  'serverDevId': '76',
  'vSwtichKey': ''},
 {'ip': '',
  'mask': '',
  'nicName': 'vmnic4',
  'serverDevId': '76',
  'vSwtichKey': ''},
 {'ip': '',
  'mask': '',
  'nicName': 'vmnic5',
  'serverDevId': '76',
  'vSwtichKey': ''}]


    """
    hostId = get_dev_details(hostip, auth, url)['id']
    get_vm_host_vnic_url = "/imcrs/vrm/host/vnic?hostDevId=" + str(hostId)
    f_url = url + get_vm_host_vnic_url
    payload = None
    r = requests.get(f_url, auth=auth,
                     headers=HEADERS)  # creates the URL using the payload variable as the contents
    # print(r.status_code)
    try:
        if r.status_code == 200:
            if len(r.text) > 0:
                return json.loads(r.text)['Nic']
        elif r.status_code == 204:
            print("Device is not a supported Hypervisor")
            return "Device is not a supported Hypervisor"
    except requests.exceptions.RequestException as e:
            return "Error:\n" + str(e) + " get_vm_host_info: An Error has occured"

def get_host_vms(hostip, auth, url):
    """
    function takes hostId as input to RESTFUL call to HP IMC

    :param hostId: int or string of HostId of Hypervisor host

    :param auth: requests auth object #usually auth.creds from auth pyhpeimc.auth.class

    :param url: base url of IMC RS interface #usually auth.url from pyhpeimc.auth.authclass

    :return: list of dictionaries where each element of the list represents a single virtual machine which is currently
    located on the target host.

    :rtype: list

    >>> from pyhpeimc.auth import *

    >>> from pyhpeimc.plat.vrm import *

    >>> auth = IMCAuth("http://", "10.101.0.203", "8080", "admin", "admin")

    >>>get_host_vms('10.101.0.6', auth.creds, auth.url)
[{'coresPerCpu': '1',
  'cpu': '2',
  'memory': '8192',
  'osDesc': 'SUSE Linux Enterprise 11 (64-bit)',
  'parentServerId': '76',
  'porductFlag': '0',
  'powerState': '2',
  'vmDevId': '56',
  'vmIP': '10.101.0.5',
  'vmMask': ' ',
  'vmName': 'vcenter6',
  'vmTools': '2'},
 {'coresPerCpu': '1',
  'cpu': '1',
  'memory': '4096',
  'osDesc': 'Microsoft Windows Server 2012 (64-bit)',
  'parentServerId': '76',
  'porductFlag': '0',
  'powerState': '2',
  'vmDevId': '57',
  'vmIP': '10.101.0.20',
  'vmMask': ' ',
  'vmName': '2016 Microsoft Server 2012R2 AD + DHCP 10.101.0.20',
  'vmTools': '2'},
 {'coresPerCpu': '4',
  'cpu': '1',
  'memory': '12288',
  'osDesc': 'Microsoft Windows Server 2012 (64-bit)',
  'parentServerId': '76',
  'porductFlag': '0',
  'powerState': '2',
  'vmDevId': '67',
  'vmIP': '10.101.0.203',
  'vmMask': ' ',
  'vmName': 'HPE IMC 7.2 Jan 2016 10.101.0.203',
  'vmTools': '2'},
 {'coresPerCpu': '1',
  'cpu': '1',
  'memory': '4096',
  'osDesc': 'Microsoft Windows Server 2012 (64-bit)',
  'parentServerId': '76',
  'porductFlag': '0',
  'powerState': '2',
  'vmDevId': '71',
  'vmIP': '10.101.0.202',
  'vmMask': ' ',
  'vmName': 'HP IMC 7.1 June 2015 10.101.0.202',
  'vmTools': '2'},
 {'coresPerCpu': '1',
  'cpu': '2',
  'memory': '4096',
  'osDesc': 'Other (64-bit)',
  'parentServerId': '76',
  'porductFlag': '0',
  'powerState': '3',
  'vmDevId': '147',
  'vmIP': ' ',
  'vmMask': ' ',
  'vmName': 'F5 BIG-IP VE 11.3.0.2806.0',
  'vmTools': '14'},
 {'coresPerCpu': '1',
  'cpu': '1',
  'memory': '4096',
  'osDesc': 'Microsoft Windows Server 2012 (64-bit)',
  'parentServerId': '76',
  'porductFlag': '0',
  'powerState': '3',
  'vmDevId': '148',
  'vmIP': ' ',
  'vmMask': ' ',
  'vmName': 'RSM 7.0 10.101.0.191',
  'vmTools': '14'},
 {'coresPerCpu': '1',
  'cpu': '1',
  'memory': '4096',
  'osDesc': 'Microsoft Windows Server 2012 (64-bit)',
  'parentServerId': '76',
  'porductFlag': '0',
  'powerState': '3',
  'vmDevId': '149',
  'vmIP': ' ',
  'vmMask': ' ',
  'vmName': 'RSM 7.2 10.101.0.193',
  'vmTools': '14'},
 {'coresPerCpu': '1',
  'cpu': '1',
  'memory': '6144',
  'osDesc': 'CentOS 4/5/6 (32-bit)',
  'parentServerId': '76',
  'porductFlag': '0',
  'powerState': '3',
  'vmDevId': '151',
  'vmIP': ' ',
  'vmMask': ' ',
  'vmName': 'HP vSMS new',
  'vmTools': '14'},
 {'coresPerCpu': '1',
  'cpu': '2',
  'memory': '2816',
  'osDesc': 'Other (32-bit)',
  'parentServerId': '76',
  'porductFlag': '0',
  'powerState': '32769',
  'vmDevId': '152',
  'vmIP': ' ',
  'vmMask': ' ',
  'vmName': 'HP IMC UCHM Demo (2)',
  'vmTools': '14'},
 {'coresPerCpu': '2',
  'cpu': '1',
  'memory': '8192',
  'osDesc': 'Microsoft Windows Server 2012 (64-bit)',
  'parentServerId': '76',
  'porductFlag': '0',
  'powerState': '2',
  'vmDevId': '153',
  'vmIP': ' ',
  'vmMask': ' ',
  'vmName': '2014 Home IMC 10.3.10.220',
  'vmTools': '12'},
 {'coresPerCpu': '1',
  'cpu': '1',
  'memory': '4096',
  'osDesc': 'Microsoft Windows Server 2012 (64-bit)',
  'parentServerId': '76',
  'porductFlag': '0',
  'powerState': '3',
  'vmDevId': '154',
  'vmIP': ' ',
  'vmMask': ' ',
  'vmName': 'Solarwinds Orion',
  'vmTools': '12'},
 {'coresPerCpu': '1',
  'cpu': '2',
  'memory': '4096',
  'osDesc': 'Ubuntu Linux (64-bit)',
  'parentServerId': '76',
  'porductFlag': '0',
  'powerState': '32769',
  'vmDevId': '155',
  'vmIP': ' ',
  'vmMask': ' ',
  'vmName': 'CiscoONEPK_AIO',
  'vmTools': '12'},
 {'coresPerCpu': '1',
  'cpu': '1',
  'memory': '4096',
  'osDesc': 'Microsoft Windows Server 2012 (64-bit)',
  'parentServerId': '76',
  'porductFlag': '0',
  'powerState': '32769',
  'vmDevId': '156',
  'vmIP': ' ',
  'vmMask': ' ',
  'vmName': 'HP IMC 5.2 10.101.0.200',
  'vmTools': '14'},
 {'coresPerCpu': '1',
  'cpu': '2',
  'memory': '8192',
  'osDesc': 'SUSE Linux Enterprise 11 (64-bit)',
  'parentServerId': '76',
  'porductFlag': '0',
  'powerState': '3',
  'vmDevId': '157',
  'vmIP': ' ',
  'vmMask': ' ',
  'vmName': 'vCenter Server Appliance 2014 10.101.0.5',
  'vmTools': '14'},
 {'coresPerCpu': '1',
  'cpu': '1',
  'memory': '4096',
  'osDesc': 'Microsoft Windows Server 2012 (64-bit)',
  'parentServerId': '76',
  'porductFlag': '0',
  'powerState': '3',
  'vmDevId': '158',
  'vmIP': ' ',
  'vmMask': ' ',
  'vmName': 'vCenter Windows Sept 2015 10.101.0.9',
  'vmTools': '14'},
 {'coresPerCpu': '1',
  'cpu': '2',
  'memory': '8192',
  'osDesc': 'SUSE Linux Enterprise 11 (64-bit)',
  'parentServerId': '76',
  'porductFlag': '0',
  'powerState': '3',
  'vmDevId': '159',
  'vmIP': ' ',
  'vmMask': ' ',
  'vmName': 'VMware vCenter Server Appliance 2016 10.101.0.5',
  'vmTools': '14'},
 {'coresPerCpu': '1',
  'cpu': '1',
  'memory': '4096',
  'osDesc': 'Microsoft Windows Server 2012 (64-bit)',
  'parentServerId': '76',
  'porductFlag': '0',
  'powerState': '2',
  'vmDevId': '229',
  'vmIP': '10.101.0.201',
  'vmMask': ' ',
  'vmName': 'HP IMC 7.0 10.101.0.201',
  'vmTools': '2'}]

    """
    hostId = get_dev_details(hostip, auth, url)['id']
    get_host_info_url = "/imcrs/vrm/host/vm?hostId=" + str(hostId)
    f_url = url + get_host_info_url
    payload = None
    r = requests.get(f_url, auth=auth,
                     headers=HEADERS)  # creates the URL using the payload variable as the contents
    try:
        if r.status_code == 200:
            if len(json.loads(r.text)) > 1:
                return json.loads(r.text)['vmDevice']
            else:
                return "Device is not a supported Hypervisor"
    except requests.exceptions.RequestException as e:
            return "Error:\n" + str(e) + " get_host_vms: An Error has occured"



#!/usr/bin/env python3
# author: @netmanchris



# This section imports required libraries
import json
import requests



HEADERS = {'Accept': 'application/json', 'Content-Type':
    'application/json', 'Accept-encoding': 'application/json'}

def get_ac_info_all(auth, url):
    """
    function takes no input as input to RESTFUL call to HP IMC

    :param auth: requests auth object #usually auth.creds from auth pyhpeimc.auth.class

    :param url: base url of IMC RS interface #usually auth.url from pyhpeimc.auth.authclass

    :return: list of dictionaries where each element of the list represents a single wireless controller which has been
    discovered in the HPE IMC WSM module

    :rtype: list

    >>> from pyhpeimc.auth import *

    >>> from pyhpeimc.wsm.acinfo import *

    >>> auth = IMCAuth("http://", "10.101.0.203", "8080", "admin", "admin")

    >>> get_ac_info_all(auth.creds, auth.url)
    [{'hardwareVersion': '',
  'ipAddress': '10.10.10.5',
  'label': 'HP830_WSC',
  'macAddress': 'd0:7e:28:80:40:0c',
  'onlineApCount': '2',
  'onlineClientCount': '5',
  'pingStatus': '1',
  'serialId': '',
  'softwareVersion': 'Release 3507P51',
  'status': '3',
  'sysName': 'HP830_WSC',
  'type': 'HP 830-24P'},
 {'hardwareVersion': '',
  'ipAddress': '10.101.0.235',
  'label': 'aruba3600.lab.local',
  'macAddress': '',
  'onlineApCount': '1',
  'onlineClientCount': '0',
  'pingStatus': '1',
  'serialId': '',
  'softwareVersion': '',
  'status': '1',
  'sysName': 'Aruba3600',
  'type': 'Aruba 3600'},
 {'hardwareVersion': '',
  'ipAddress': '10.101.0.236',
  'label': 'Aruba7010',
  'macAddress': '',
  'onlineApCount': '4',
  'onlineClientCount': '0',
  'pingStatus': '0',
  'serialId': '',
  'softwareVersion': '',
  'status': '5',
  'sysName': 'Aruba7010',
  'type': 'Aruba 7010 Controller'},
 {'hardwareVersion': '',
  'ipAddress': '10.101.0.241',
  'label': 'SG9483N00P',
  'macAddress': '',
  'onlineApCount': '0',
  'onlineClientCount': '0',
  'pingStatus': '0',
  'serialId': '',
  'softwareVersion': '',
  'status': '5',
  'sysName': 'SG9483N00P',
  'type': 'HP MultiService Controllers MSM760'}]

    """
    get_ac_info_all_url = "/imcrs/wlan/acInfo/queryAcBasicInfo"
    f_url = url + get_ac_info_all_url
    payload = None
    r = requests.get(f_url, auth=auth,
                     headers=HEADERS)  # creates the URL using the payload variable as the contents
    # print(r.status_code)
    try:
        if r.status_code == 200:
            if len(r.text) > 0:
                return json.loads(r.text)['acBasicInfo']
    except requests.exceptions.RequestException as e:
            return "Error:\n" + str(e) + " get_ac_info_all: An Error has occured"